/**
 * Method: same as the 100p method, but on 64-bit integers, using explicit
 * denominators and performing multiplications.
 */
#include <stdio.h>

#define MAX_W 400

typedef unsigned long long u64;
typedef struct {
  u64 p, q;
} frac;

frac a[MAX_W][MAX_W];

u64 gcd(u64 a, u64 b) {
  while (b) {
    u64 t = a % b;
    a = b;
    b = t;
  }
  return a;
}

int main() {
  int n, k, w, l, i, j;

  FILE *f = fopen("spoiler.in", "r");
  fscanf(f, "%d%d", &n, &k);
  fclose(f);

  w = (n + 1) / 2; /* winner's points */
  l = k - w;       /* loser's points */

  for (j = 0; j <= l; j++) {
    a[w][j] = (frac) { 0, 1 };
  }

  for (i = w - 1; i >= 0; i--) {
    int lim = (i < l) ? i : l;
    for (j = lim; j >= 0; j--) {
      if (i == j) {
        /* a[i][j] = 1 + a[i + 1][j] */
        a[i][j] = (frac) {
          a[i + 1][j].p + a[i + 1][j].q,
          a[i + 1][j].q
        };
      } else if ((i > l) && (j == l)) {
        a[i][j] = a[i + 1][j];
      } else if ((i == w - 1) && (j < l)) {
        a[i][j] = a[i][j + 1];
      } else {
        /* a[i][j] = 1 + 1/2 * (a[i][j + 1] + a[i + 1][j]) */
        a[i][j] = (frac) {
          2 * a[i + 1][j].q * a[i][j + 1].q +
          a[i + 1][j].p * a[i][j + 1].q +
          a[i][j + 1].p * a[i + 1][j].q,
          2 * a[i + 1][j].q * a[i][j + 1].q
        };
        if (a[i][j].q) {
          u64 d = gcd(a[i][j].p, a[i][j].q);
          a[i][j] = (frac) { a[i][j].p / d, a[i][j].q / d };
        }
      }
    }
  }

  f = fopen("spoiler.out", "w");
  fprintf(f, "%llu\n%llu\n", a[0][0].p, a[0][0].q);
  fclose(f);

  return 0;
}
