/**
 * Method: same as the 100p method, but stores the denominators explicitly
 * and performs naive multiplications.
 **/
#include <stdio.h>
#include <string.h>

#define MAX_W 1000
#define MAX_DIGITS 1220 /* twice as many, due to multiplications */
#define MIN(X, Y) (((X) < (Y)) ? (X) : (Y))

typedef struct {
  int n;
  char d[MAX_DIGITS];
} huge;

huge p[MAX_W];
huge q[MAX_W];

int buf[MAX_DIGITS]; /* buffer for the naive multiplication */

void print(huge *h, FILE *f) {
  int i;

  for (i = h->n - 1; i >= 0; i--) {
    fprintf(f, "%d", h->d[i]);
  }
  fprintf(f, "\n");
}

int even(huge *h) {
  return !(h->d[0] & 1);
}

/* h *= 2 */
void twice(huge *h) {
  int c = 0, i;

  for (i = 0; i < h->n; i++) {
    h->d[i] = (h->d[i] << 1) + c;
    c = (h->d[i] >= 10);
    h->d[i] -= 10 * c;
  }
  if (c) {
    h->d[h->n++] = 1;
  }
}

/* h /= 2 */
void half(huge *h) {
  int c = 0, i;

  for (i = h->n - 1; i >= 0; i--) {
    h->d[i] += 10 * c;
    c = h->d[i] & 1;
    h->d[i] >>= 1;
  }
  if (h->n && !h->d[h->n - 1]) {
    h->n--;
  }
}

/* a += b */
void sum(huge *a, huge *b) {
  while (a->n < b->n) {
    a->d[a->n++] = 0;
  }

  int i, c = 0;
  for (i = 0; (i < b->n) || ((i < a->n) && c); i++) {
    a->d[i] += ((i < b->n) ? b->d[i] : 0) + c;
    c = (a->d[i] >= 10);
    a->d[i] -= 10 * c;
  }
  if (c) {
    a->d[a->n++] = 1;
  }
}

/* c = a * b */
void mult(huge *a, huge *b, huge *c) {
  int i, j, carry;

  memset(buf, 0, sizeof(buf));
  for (i = 0; i < a->n; i++) {
    for (j = 0; j < b->n; j++) {
      buf[i + j] += a->d[i] * b->d[j];
    }
  }

  carry = 0;
  for (i = 0; (i < a->n + b->n) || carry; i++) {
    buf[i] += carry;
    carry = buf[i] / 10;
    c->d[i] = buf[i] - 10 * carry;
  }

  c->n = i;
  while (c->n && !c->d[c->n - 1]) {
    c->n--;
  }
}

int main() {
  int n, k, w, l, i, s;

  FILE *f = fopen("spoiler.in", "r");
  fscanf(f, "%d%d", &n, &k);
  fclose(f);

  w = (n + 1) / 2; /* winner's points */
  l = k - w;       /* loser's points */

  for (i = 0; i <= l + 1; i++) {
    q[i].n = 1;
    q[i].d[0] = 1;
  }

  huge t1, t2;
  for (s = k - 1; s >= 0; s--) {
    for (i = MIN(s, w - 1); i >= s - i; i--) {
      int j = s - i;
      if (i == j) {
        /* S(i, j) = 1 + S(i + 1, j) */
        sum(&p[j], &q[j]);
      } else if ((i > l) && (j == l)) {
        /* nothing to do: S(i, j) = S(i + 1, j) */
      } else if ((i == w - 1) && (j < l)) {
        /* S(i, j) = S(i, j + 1) */
        p[j] = p[j + 1];
        q[j] = q[j + 1];
      } else {
        /* S(i, j) = 1 + 1/2 * (S(i + 1, j) + S(i, j + 1)) */
        /* or p/q = 1 + 1/2 * (p1 / q1 + p2 / q2) */
        /* or p/q = (2 * q1 * q2 + p1 * q2 + p2 * q1) / (2 * q1 * q2) */
        mult(&p[j], &q[j + 1], &t1);
        mult(&p[j + 1], &q[j], &t2);
        sum(&t1, &t2);
        mult(&q[j], &q[j + 1], &t2);
        twice(&t2);
        sum(&t1, &t2);
        p[j] = t1;
        q[j] = t2;
        while (even(&p[j]) && even(&q[j]) && q[j].n) {
          half(&p[j]);
          half(&q[j]);
        }
      }
    }
  }

  f = fopen("spoiler.out", "w");
  print(&p[0], f);
  print(&q[0], f);
  fclose(f);

  return 0;
}
